==> com.liferay.friendly.url.service-2.0.22-sources.jar: com/liferay/friendly/url/internal/model/listener/FriendlyURLEntryStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.friendly.url.internal.model.listener;

import com.liferay.friendly.url.model.FriendlyURLEntry;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class FriendlyURLEntryStagingModelListener
	extends BaseModelListener<FriendlyURLEntry> {

	@Override
	public void onAfterCreate(FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(friendlyURLEntry);
	}

	@Override
	public void onAfterRemove(FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(friendlyURLEntry);
	}

	@Override
	public void onAfterUpdate(FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(friendlyURLEntry);
	}

	@Reference
	private StagingModelListener<FriendlyURLEntry> _stagingModelListener;

}

==> com.liferay.friendly.url.service-4.0.41-sources.jar: com/liferay/friendly/url/internal/model/listener/FriendlyURLEntryStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.friendly.url.internal.model.listener;

import com.liferay.friendly.url.model.FriendlyURLEntry;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class FriendlyURLEntryStagingModelListener
	extends BaseModelListener<FriendlyURLEntry> {

	@Override
	public void onAfterCreate(FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(friendlyURLEntry);
	}

	@Override
	public void onAfterRemove(FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(friendlyURLEntry);
	}

	@Override
	public void onAfterUpdate(
			FriendlyURLEntry originalFriendlyURLEntry,
			FriendlyURLEntry friendlyURLEntry)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(friendlyURLEntry);
	}

	@Reference
	private StagingModelListener<FriendlyURLEntry> _stagingModelListener;

}
